==> gnome-games-0.26.tar.gz: gnome-games-0.26/gnothello/gnothello.h <==
/*
 * gnothello.h - Header for gnothello.c
 * written by Ian Peters <ipeters@acm.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For more details see the file COPYING.
 */

#define GNOTHELLO_VERSION "0.2.0"
#define PIXMAP_NAME "tiles.png"
#define BLACK_TURN 1
#define WHITE_TURN 31
#define PIXMAP_FLIP_DELAY 20
#define COMPUTER_MOVE_DELAY 1000

#define TILEWIDTH 60
#define TILEHEIGHT 60
#define BOARDWIDTH TILEWIDTH * 8
#define BOARDHEIGHT TILEHEIGHT * 8

void new_game_cb(GtkWidget *widget, gpointer data);
void quit_game_cb(GtkWidget *widget, gpointer data);
void black_level_cb (GtkWidget *widget, gpointer data);
void white_level_cb (GtkWidget *widget, gpointer data);
void about_cb (GtkWidget *widget, gpointer data);
void comp_black_cb (GtkWidget *widget, gpointer data);
void comp_white_cb (GtkWidget *widget, gpointer data);
void quick_moves_cb (GtkWidget *widget, gpointer data);
void anim_cb (GtkWidget *widget, gpointer data);
void anim_stagger_cb (GtkWidget *widget, gpointer data);
gint expose_event (GtkWidget *widget ,GdkEventExpose *event);
gint configure_event (GtkWidget *widget, GdkEventConfigure *event);
gint button_press_event (GtkWidget *widget, GdkEventButton *event);
void gui_draw_pixmap(gint which, gint x, gint y);
void gui_draw_pixmap_buffer(gint which, gint x, gint y);
gint flip_pixmaps(gpointer data);
void init_new_game();
void create_window();
void create_menus();
void create_drawing_area();
void create_statusbar();
void gui_message(gchar *message);
guint check_computer_players();

==> gnome-games-0.99.1.tar.gz: gnome-games-0.99.1/gnothello/gnothello.h <==
/*
 * gnothello.h - Header for gnothello.c
 * written by Ian Peters <ipeters@acm.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For more details see the file COPYING.
 */

#define GNOTHELLO_VERSION "0.8.0"
#define BLACK_TURN 1
#define WHITE_TURN 31
#define PIXMAP_FLIP_DELAY 20
#define PIXMAP_STAGGER_DELAY 3
#define COMPUTER_MOVE_DELAY 1000

#define TILEWIDTH 60
#define TILEHEIGHT 60
#define BOARDWIDTH TILEWIDTH * 8
#define BOARDHEIGHT TILEHEIGHT * 8

typedef struct _MoveHistory MoveHistory;

struct _MoveHistory
{
        gint8 board[8][8];
        gint8 x;
        gint8 y;
	gint8 me;
};

void new_game_cb(GtkWidget *widget, gpointer data);
void new_net_game_cb(GtkWidget *widget, gpointer data);
void quit_game_cb(GtkWidget *widget, gpointer data);
void undo_move_cb(GtkWidget *widget, gpointer data);
void redo_move_cb(GtkWidget *widget, gpointer data);
void black_level_cb (GtkWidget *widget, gpointer data);
void white_level_cb (GtkWidget *widget, gpointer data);
void about_cb (GtkWidget *widget, gpointer data);
void comp_black_cb (GtkWidget *widget, gpointer data);
void comp_white_cb (GtkWidget *widget, gpointer data);
void quick_moves_cb (GtkWidget *widget, gpointer data);
void anim_cb (GtkWidget *widget, gpointer data);
void anim_stagger_cb (GtkWidget *widget, gpointer data);
void load_tiles_cb(GtkWidget *widget, gpointer data);
void fill_menu(GtkWidget *menu);
void set_selection(GtkWidget *widget, void *data);
void free_str(GtkWidget *widget, void *data);
void load_tiles_callback(GtkWidget *widget, void *data);
void cancel(GtkWidget *widget, void *data);
gint expose_event (GtkWidget *widget ,GdkEventExpose *event);
gint configure_event (GtkWidget *widget, GdkEventConfigure *event);
gint button_press_event (GtkWidget *widget, GdkEventButton *event);
void gui_draw_pixmap(gint which, gint x, gint y);
void gui_draw_pixmap_buffer(gint which, gint x, gint y);
gint flip_pixmaps(gpointer data);
void init_new_game();
void create_window();
void gui_status();
void gui_message(gchar *message);
guint check_computer_players();
void load_pixmaps();

extern guint whose_turn;
